// ***************************************
//	uart2313.c
// ***************************************

#include "uart2313.h"

// ***************************************
// **** Initialize UART ******************	
// ***************************************

//void init_UART( void ) {

void init_UART( unsigned long cpu_freq, unsigned long baudrate ) {

// calculate baud prescale value
	unsigned long baud_prescale = (((cpu_freq / (baudrate * 8UL))) - 1);	// Double speed mode calculation for UBRR

// **** Enable Rx and Tx *****************

	UCSRB = (1 << RXEN) | (1 << TXEN)					// Enable Receive and Transmit
		| (0 << RXCIE);									// Rx interrupt not enabled by default, use en_Rx() function

// **** Default frame format: 8data, 1 stop ****

// **** Set baud rate ********************

	UBRRL = baud_prescale;									
	UBRRH = (baud_prescale >> 8);

	UCSRA |= (1 << U2X);								// Set double baud rate
}

// ***************************************
// **** UART Transmit ********************	
// ***************************************

void Tx( unsigned char data ) {
	
// **** Wait for empty Tx buffer *********

	while( (UCSRA & (1 << UDRE)) == 0 ){};

// **** Put data in buffer, send data ****

	UDR = data;
}

// ***************************************
// **** UART Receive *********************	
// ***************************************

unsigned char Rx( void ) {

// **** Wait for data to be received *****

	while( (UCSRA & (1 << RXC)) == 0 ){};

// **** Return received data in buffer ***

	return UDR;
}

void en_Rx( void ) {

	sei();												// Enable global interrupts
	UCSRB |= (1 << RXCIE);								// Enable Rx interrupt
}

void dis_Rx( void ) {

	UCSRB &= ~(1 << RXCIE);								// Disable Rx interrupt
}
